# Contributors

## Nils Eling 

[nils.eling@uzh.ch](mailto:nils.eling@uzh.ch)

  - Logo
  - Documentation
  - [imcRtools](https://github.com/BodenmillerGroup/imcRtools)::`read_steinbock`
  - Testing, feedback & discussion
